@@ -18,8 +18,8 @@
 #define TOSTRING(x)  STRINGIFY(x)
 #endif
 
-#define VIZIONSDK_VERSION_MAJOR 25
-#define VIZIONSDK_VERSION_MINOR 12
+#define VIZIONSDK_VERSION_MAJOR 26
+#define VIZIONSDK_VERSION_MINOR 1
 #define VIZIONSDK_VERSION_PATCH 0
 #define VIZIONSDK_VERSION_BUILD 1
 
@@ -159,4 +159,18 @@ std::shared_ptr<VxRoute> VIZIONSDK_API VxLoadRouteYaml(const std::string& yamlPa
 int VIZIONSDK_API VxActivateYamlRoutes(std::shared_ptr<VxRoute> yamlRoutes);
 
 /* Sensor Work Mode */
-int VIZIONSDK_API VxGetSensorWorkMode(std::shared_ptr<VxCamera> vxcam, VX_SENSOR_MODE& mode);
\ No newline at end of file
+int VIZIONSDK_API VxGetSensorWorkMode(std::shared_ptr<VxCamera> vxcam, VX_SENSOR_MODE& mode);
+
+/* IMU Data*/
+int VIZIONSDK_API VxEnableIMUMode(std::shared_ptr<VxCamera> vxcam, VX_IMU_MODE mode);
+int VIZIONSDK_API VxRebootIMUMode(std::shared_ptr<VxCamera> vxcam, VX_IMU_MODE mode);
+int VIZIONSDK_API VxGetIMUAccData(std::shared_ptr<VxCamera> vxcam, std::vector<float>& accArr, VX_IMU_SELF_TEST_MODE mode);
+int VIZIONSDK_API VxGetIMUGyrData(std::shared_ptr<VxCamera> vxcam, std::vector<float>& gyrArr, VX_IMU_SELF_TEST_MODE mode);
+int VIZIONSDK_API VxGetISPUData(std::shared_ptr<VxCamera> vxcam, VxImuIspu& ispuData);
+int VIZIONSDK_API VxGetIMUTemperature(std::shared_ptr<VxCamera> vxcam, float& temperature);
+int VIZIONSDK_API VxGetIMUSensorTime(std::shared_ptr<VxCamera> vxcam, float& sensorTime);
+
+/* Custom information modification */
+int VIZIONSDK_API VxFlashProductInfo(std::shared_ptr<VxCamera> vxcam, std::string imgPath);
+int VIZIONSDK_API VxWriteIntrinsics(std::shared_ptr<VxCamera> vxcam, VxIntrinsics intrinsics);
+int VIZIONSDK_API VxGetIntrinsics(std::shared_ptr<VxCamera> vxcam, VxIntrinsics& intrinsics);
\ No newline at end of file
