@@ -50,45 +50,6 @@ enum class VX_FX3_FW_TARGET {
     FW_TARGET_SPI       /* Program firmware (hex) to SPI    */
 };
 
-#pragma pack(push, 1)
-struct VxHeaderV2 {  // Header Version 3
-    uint8_t headerVersion;
-    uint16_t contentOffset;
-    uint8_t productName[64];
-    uint8_t productVersion;
-    uint8_t headInfo[64];
-    uint8_t lensVersion;
-    uint8_t contentVersion;
-    uint32_t contentChecksum;
-    uint32_t contentLen;
-    uint16_t pllBootdataLen;
-};
-struct VxHeaderV3 {  // Header Version 3
-    // Fixed Area
-    uint8_t headerVersion;
-    uint16_t contentOffset;
-    uint16_t sensorType;
-    uint8_t sensorFuseId[16];
-    uint8_t productName[64];
-    uint8_t lensId[16];
-    uint16_t fixChecksum;
-    // Dynamic update area
-    uint8_t tnFwVersion[2];
-    uint16_t vendorFwVersion;
-    uint16_t customNumber;  // or revision number
-    uint8_t recordYear;
-    uint8_t recordMonth;
-    uint8_t recordDay;
-    uint8_t recordHour;
-    uint8_t recordMinute;
-    uint8_t recordSecond;
-    uint16_t mipiDatarate;
-    uint32_t contentLen;
-    uint16_t contentChecksum;
-    uint16_t totalChecksum;
-};
-#pragma pack(pop)
-
 enum class VX_CAMERA_PRODUCT_TYPE {
     VXCAM_PRODUCT_TYPE_NONE_CAMERA,
     VXCAM_PRODUCT_TYPE_GENERIC_CAMERA,
@@ -97,6 +58,7 @@ enum class VX_CAMERA_PRODUCT_TYPE {
     VXCAM_PRODUCT_TYPE_TEVS,
     VXCAM_PRODUCT_TYPE_TEVI,
     VXCAM_PRODUCT_TYPE_OV5640,
+    VXCAM_PRODUCT_TYPE_TEVM,
 
     CLASS_TYPE_SIZE
 };
@@ -158,6 +120,7 @@ enum class VX_ISP_IMAGE_PROPERTIES {
     ISP_EHDR_RATIO_MAX,
     ISP_EHDR_ATM_WEIGHT,  // Experimental: still under testing
     ISP_EHDR_ATM_MAX,     // Experimental: still under testing
+    ISP_IMAGE_IMU_MODE,
     ISP_IMAGE_PROP_MAX
 };
 
@@ -223,17 +186,50 @@ enum class VX_EHDR_MODE {
 
 enum class VX_OSP_PROFILE_FLAG { DISABLED, ENABLED, ENABLED_AND_SAVE };
 
-enum class VX_MCU_TYPE {
-    TI,
-    NXP,
-    UNKNOWN,
-};
-
 enum class VX_SENSOR_MODE {
     STANDBY,
     WORK,
 };
 
+enum class VX_IMU_MODE {
+    DISABLE,
+    ISPU,
+    SELF_TEST,
+};
+
+enum class VX_IMU_SELF_TEST_MODE {
+    NORMAL,
+    POSITIVE,
+    NEGATIVE,
+    NOT_ALLOWED,
+};
+
+struct VxImuIspu {
+    float x;
+    float y;
+    float z;
+    float w;
+    float yaw;
+    float pitch;
+    float roll;
+};
+
+enum class VX_DISTORTION_MODEL {
+    VX_DIST_NONE,
+    VX_DIST_MODEL_RADTAN
+};
+
+struct VxIntrinsics {
+    int w;
+    int h;
+    float fx; // Focal Length U
+    float fy; // Focal Length V
+    float cx; // Principal Point U
+    float cy; // Principal Point V
+    VX_DISTORTION_MODEL model;
+    float coeffs[5]; // k1~k3,r1,r2
+};
+
 //* Profile Constants *//
 // UVC Profile Name
 #define VZCAM_UVC_PROFILE_NAME_EXPOSURE_TIME            "ExposureTime"
